'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _package = require('../../package.json');

var _package2 = _interopRequireDefault(_package);

var _loader = require('./loader');

var _loader2 = _interopRequireDefault(_loader);

var _commandList = require('./commands/command-list');

var _commandList2 = _interopRequireDefault(_commandList);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function bitError(message) {
  return _chalk2.default.red(`${message.split('\n') // eslint-disable-line
  .map(function (m) {
    return `bitjs ERR! ${m}`;
  }).join('\n')}\n`);
}


function errorHandler(e) {
  _loader2.default.off();
  process.stderr.write(bitError(e.message));
  if (e.code) {
    process.stderr.write(bitError(`\ncode: ${e.code}\n`));
  }
  process.stderr.write(bitError(e.stack));
  process.exit(1);
}

function logAndExit(str) {
  _loader2.default.off();
  if (str) {
    console.log(str); // eslint-disable-line
  }
  process.exit(0);
}

function start() {
  _commander2.default.version(_package2.default.version).description('bit driver for javascript');
  _commandList2.default.forEach(function (c) {
    var currentCommand = _commander2.default.command(c.name).description(c.description);

    if (c.options && Array.isArray(c.options)) {
      c.options.forEach(function (option) {
        return currentCommand.option(`${option.alias} ${option.name}`, option.description);
      });
    }

    currentCommand.action(function (args, options) {
      if (c.loader === true) _loader2.default.on();
      _loader2.default.start(c.loaderText || `performing ${c.name} command`);
      c.action(args, options).then(c.report).then(logAndExit).catch(c.handleError || errorHandler);
    });
  });

  _commander2.default.parse(process.argv);
}

exports.default = start;
//# sourceMappingURL=command-registrar.js.map